@@ -6,7 +6,6 @@ from typing import List, Optional, Tuple
 
 from whichcraft import which
 
-from . import dtslogger
 from .config import read_shell_config
 from .exceptions import InvalidEnvironment, UserError
 
@@ -62,7 +61,7 @@ def check_docker_environment():
         client = docker.from_env()
 
         # TODO: why are we doing this? It seems expensive and useless
-        _containers = client.containers.list(filters=dict(status="running"))
+        # _containers = client.containers.list(filters=dict(status="running"))
 
         # dtslogger.debug(json.dumps(client.info(), indent=4))
 
@@ -97,7 +96,7 @@ def check_user_in_docker_group() -> None:
         if group_id not in my_groups:
             msg = 'My groups are %s and "%s" group is %s ' % (my_groups, G, group_id)
             msg += "\n\nNote that when you add a user to a group, you need to login in and out."
-            dtslogger.debug(msg)
+            # dtslogger.debug(msg)
 
 
 def get_active_groups(username: Optional[str] = None) -> List[str]:
