@@ -77,6 +77,7 @@ def print_version_info() -> None:
     }
 
     try:
+        # noinspection PyCompatibility,PyUnresolvedReferences
         from pip._internal.utils.misc import get_installed_distributions
     except ImportError:
         dtslogger.warning('Please update "pip" to have better debug info.')
@@ -124,7 +125,7 @@ def print_info_command() -> None:
 
 def cli_main_() -> None:
     abort_if_running_with_sudo()
-    print_info_command()
+
     # Problems with a step in the Duckiebot operation manual?
     #
     #     Report here: https://github.com/duckietown/docs-opmanual_duckiebot/issues
@@ -133,6 +134,9 @@ def cli_main_() -> None:
     cli_arguments = sys.argv[1:]
     cli_options, arguments = get_cli_options(cli_arguments)
 
+    if not cli_options.quiet:
+        print_info_command()
+
     # process options here
     if cli_options.debug:
         dtslogger.setLevel(logging.DEBUG)
@@ -173,8 +177,8 @@ def cli_main_() -> None:
         where <version> = daffy, master19
         """
         raise UserError(msg)
-
-    dtslogger.info(f"Commands version: {shell_config.duckietown_version}")
+    if not cli_options.quiet:
+        dtslogger.info(f"Commands version: {shell_config.duckietown_version}")
     commands_info = get_local_commands_info()
     # add subdirectory for version
     if not commands_info.leave_alone:
